ibreakdown
==========
.. image:: https://travis-ci.com/jettify/ibreakdown.svg?branch=master
    :target: https://travis-ci.com/jettify/ibreakdown
.. image:: https://codecov.io/gh/jettify/ibreakdown/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/jettify/ibreakdown
.. image:: https://img.shields.io/pypi/pyversions/ibreakdown.svg
    :target: https://pypi.org/project/ibreakdown
.. image:: https://img.shields.io/pypi/v/ibreakdown.svg
    :target: https://pypi.python.org/pypi/ibreakdown


**ibreakdown** is model agnostic predictions explainer with interactions support,
library can show contribution of each feature of your prediction value.
